@@ -19,7 +19,7 @@ def _pad_key(key):
         return key.ljust(16)
 
 
-def encrypt(msg, key=None):
+def encrypt(msg, key=None, url_safe=False):
     if not key:
         return msg.encode('utf-8')
     else:
@@ -28,18 +28,25 @@ def encrypt(msg, key=None):
     msg = (msg + '$').encode('utf-8')
     padded_msg = msg.ljust((len(msg) // 16 + 1) * 16)
     cipher = AES.new(key, AES.MODE_ECB)
-    encoded = base64.b64encode(cipher.encrypt(padded_msg))
+    encrypted = cipher.encrypt(padded_msg)
+    if url_safe:
+        encoded = base64.b64encode(encrypted, altchars=b'-_')
+    else:
+        encoded = base64.b64encode(encrypted)
     return encoded
 
 
-def decrypt(encoded, key=None):
+def decrypt(encoded, key=None, url_safe=False):
     if not key:
         return encoded.decode('utf-8')
     else:
         key = _pad_key(key).encode('utf-8')
 
     cipher = AES.new(key, AES.MODE_ECB)
-    decoded = base64.b64decode(encoded)
+    if url_safe:
+        decoded = base64.b64decode(encoded, altchars=b'-_')
+    else:
+        decoded = base64.b64decode(encoded)
     padded_msg = cipher.decrypt(decoded)
     msg = padded_msg.rstrip()
     msg = msg.decode('utf-8')
