@@ -29,7 +29,7 @@ def get_request_para(request, parsers=None, defaults=None):
 
 
 def get_ip(request):
-    if request.META.has_key('HTTP_X_REAL_IP'):
+    if 'HTTP_X_REAL_IP' in request.META:
         return request.META['HTTP_X_REAL_IP']
     else:
         return request.META['REMOTE_ADDR']
